==> erdpy-0.5.3b2.tar.gz: erdpy-0.5.3b2/erdpy/projects/project_cpp.py <==
import logging
import os
import subprocess
from os import path

from erdpy import dependencies, errors, myprocess, utils
from erdpy.projects.project_base import Project

logger = logging.getLogger("ProjectCpp")


class ProjectCpp(Project):
    def __init__(self, directory):
        super().__init__(directory)

    def perform_build(self):
        self.build_configuration = CppBuildConfiguration(self, self.debug)
        self.unit = self.find_file_globally("*.cpp")
        self.file_ll = self.unit.with_suffix(".ll")
        self.file_o = self.unit.with_suffix(".o")
        self.file_export = self.unit.with_suffix(".export")

        try:
            self._do_clang()
            self._do_llc()
            self._do_wasm()
        except subprocess.CalledProcessError as err:
            raise errors.BuildError(err.output)

    def _do_clang(self):
        logger.info("_do_clang")
        tool = path.join(self._get_llvm_path(), "clang-9")
        args = [
            tool,
            "-cc1", "-emit-llvm",
            "-triple=wasm32-unknown-unknown-wasm",
            "-ObjC++",
            "-std=c++17",
            "-nostdinc++",
            "-nobuiltininc",
            "-fno-builtin",
        ]
        if self.options.get("optimized", False):
            args.append("-Ofast")
        else:
            args.append("-O0")
        args.append(str(self.unit))
        myprocess.run_process(args)

    def _do_llc(self):
        logger.info("_do_llc")
        tool = path.join(self._get_llvm_path(), "llc")
        args = [tool]
        if self.options.get("optimized", False):
            args.append("-O3")
        else:
            args.append("-O0")
        args.extend(["-filetype=obj", self.file_ll, "-o", self.file_o])
        myprocess.run_process(args)

    def _do_wasm(self):
        logger.info("_do_wasm")
        tool = path.join(self._get_llvm_path(), "wasm-ld")
        args = [
            tool,
            "--no-entry",
            str(self.file_o),
            "-o", self.find_file_globally("*.cpp").with_suffix(".wasm"),
            "--strip-all",
            f"--allow-undefined",
            "--demangle"
        ]

        if self.options.get("verbose", False):
            args.append("--verbose")

        for export in self.build_configuration.exports:
            args.append(f"-export={export}")

        myprocess.run_process(args)

    def _copy_build_artifacts_to_output(self):
        wasm_file = self.find_file_globally("*.cpp").with_suffix(".wasm")
        self._copy_to_output(wasm_file)
        os.remove(wasm_file)

    def _get_llvm_path(self):
        return dependencies.get_install_directory("llvm")

    def get_dependencies(self):
        return ["llvm"]


class CppBuildConfiguration:
    def __init__(self, project, debug):
        self.project = project
        self.debug = debug
        self.exports = self._get_exports()

    def _get_exports(self):
        file_export = self.project.find_file_globally("*.export")
        lines = utils.read_lines(file_export)
        return lines

==> erdpy-0.8.2.tar.gz: erdpy-0.8.2/erdpy/projects/project_cpp.py <==
import logging
import os
import subprocess
from os import path

from erdpy import dependencies, errors, myprocess, utils
from erdpy.projects.project_base import Project

logger = logging.getLogger("ProjectCpp")


class ProjectCpp(Project):
    def __init__(self, directory):
        super().__init__(directory)

    def perform_build(self):
        self.build_configuration = CppBuildConfiguration(self, self.debug)
        self.unit = self.find_file_globally("*.cpp")
        self.file_ll = self.unit.with_suffix(".ll")
        self.file_o = self.unit.with_suffix(".o")
        self.file_export = self.unit.with_suffix(".export")

        try:
            self._do_clang()
            self._do_llc()
            self._do_wasm()
        except subprocess.CalledProcessError as err:
            raise errors.BuildError(err.output)

    def _do_clang(self):
        logger.info("_do_clang")
        tool = path.join(self._get_llvm_path(), "clang-9")
        args = [
            tool,
            "-cc1", "-emit-llvm",
            "-triple=wasm32-unknown-unknown-wasm",
            "-ObjC++",
            "-std=c++17",
            "-nostdinc++",
            "-nobuiltininc",
            "-fno-builtin",
        ]
        if self.options.get("optimized", False):
            args.append("-Ofast")
        else:
            args.append("-O0")
        args.append(str(self.unit))
        myprocess.run_process(args)

    def _do_llc(self):
        logger.info("_do_llc")
        tool = path.join(self._get_llvm_path(), "llc")
        args = [tool]
        if self.options.get("optimized", False):
            args.append("-O3")
        else:
            args.append("-O0")
        args.extend(["-filetype=obj", self.file_ll, "-o", self.file_o])
        myprocess.run_process(args)

    def _do_wasm(self):
        logger.info("_do_wasm")
        tool = path.join(self._get_llvm_path(), "wasm-ld")
        args = [
            tool,
            "--no-entry",
            str(self.file_o),
            "-o", self.find_file_globally("*.cpp").with_suffix(".wasm"),
            "--strip-all",
            f"--allow-undefined",
            "--demangle"
        ]

        if self.options.get("verbose", False):
            args.append("--verbose")

        for export in self.build_configuration.exports:
            args.append(f"-export={export}")

        myprocess.run_process(args)

    def _copy_build_artifacts_to_output(self):
        source_file = self.find_file_globally("*.cpp")
        self._copy_to_output(source_file.with_suffix(".wasm"))
        os.remove(source_file.with_suffix(".wasm"))
        os.remove(source_file.with_suffix(".ll"))
        os.remove(source_file.with_suffix(".o"))

    def _get_llvm_path(self):
        return dependencies.get_module_directory("llvm")

    def get_dependencies(self):
        return ["llvm"]


class CppBuildConfiguration:
    def __init__(self, project, debug):
        self.project = project
        self.debug = debug
        self.exports = self._get_exports()

    def _get_exports(self):
        file_export = self.project.find_file_globally("*.export")
        lines = utils.read_lines(file_export)
        return lines
